pyramid-blacksmith
==================

.. image:: https://readthedocs.org/projects/pyramid-blacksmith/badge/?version=latest
   :target: https://pyramid-blacksmith.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/mardiros/pyramid-blacksmith/actions/workflows/main.yml/badge.svg
   :target: https://github.com/mardiros/pyramid-blacksmith/actions/workflows/main.yml
   :alt: Continuous Integration

.. image:: https://codecov.io/gh/mardiros/pyramid-blacksmith/branch/main/graph/badge.svg?token=9IRABRO2LN
   :target: https://codecov.io/gh/mardiros/pyramid-blacksmith
   :alt: Coverage

Pyramid bindings for `Blacksmith`_ rest api client.


Introduction
------------

This plugin create a request proterty named ``blacksmith`` that bind
clients to do API Call using `Blacksmith`_ 


Clients are configured via the pyramid configurator and its settings.


.. _`Blacksmith`: https://pypi.org/project/blacksmith/

